# zzpy
Python3 Utilities
```shell
# pip3 install zzpy -i https://pypi.org/simple
# pip3 install zzpy --upgrade -i https://pypi.org/simple
```


# 待验证
- [ ] zgeo


# 未完成
- [ ] zexcel
- [ ] zcaptcha
- [ ] zbrowser
- [ ] zjson
- [ ] zrun
- [ ] ztime


# 已完成
- [x] zrandom
- [x] zconfig
- [x] zfile
- [x] zmongo
- [x] zmysql
- [x] zredis
- [x] zsys


# release log
* 1.0.20200721: ztime+get_month
* 1.0.9: build.sh
* 1.0.8: +get_today, +get_date
* 1.0.7: jsondumps+params
* 1.0.6: +jsondumps

